@@ -33,7 +33,10 @@ public:
         QString name;
         QString number;
         QString street;
+        QString streetNumber;
+        QString zipCode;
         QString city;
+        QString country;
     };
 
     ContactManager();
