@@ -194,6 +194,29 @@
         <translation>Danska</translation>
     </message>
 </context>
+<context>
+    <name>LogWindow</name>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="30"/>
+        <source>Incoming call log</source>
+        <translation>Samtalshistorik</translation>
+    </message>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="31"/>
+        <source>Clear log</source>
+        <translation>Nollställ samtalshistorik</translation>
+    </message>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="64"/>
+        <source>There are currently no logged calls</source>
+        <translation>Samtalshistoriken är tom</translation>
+    </message>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="134"/>
+        <source>%1 (no search results)</source>
+        <translation>%1 (inget sökresultat)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -218,6 +241,11 @@
         <source>Search</source>
         <translation>Sök</translation>
     </message>
+    <message>
+        <location filename="../../gui/mainwindow.cpp" line="76"/>
+        <source>Log</source>
+        <translation>Historik</translation>
+    </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="82"/>
         <source>Settings</source>
@@ -361,7 +389,7 @@
     <message>
         <location filename="../settings.cpp" line="168"/>
         <source>fi</source>
-        <translation>fi</translation>
+        <translation>se</translation>
     </message>
 </context>
 <context>
